@@ -16,7 +16,7 @@ df = get_data_from_github(u)
 
 ## clone a public repo
 u = 'https://github.com/imahdimir/d-TSETMC_ID-2-FirmTicker'
-repo = GithubDataRepo(u)
+repo = GitHubDataRepo(u)
 repo.clone_overwrite()
 
 ##
@@ -24,7 +24,7 @@ repo.rmdir()
 
 ## clone a public repo and commit back
 u = 'https://github.com/imahdimir/test-public'
-repo = GithubDataRepo(u)
+repo = GitHubDataRepo(u)
 repo.clone_overwrite()
 
 ##
@@ -36,7 +36,7 @@ repo.rmdir()
 
 ## clone a private repo and commit back
 ur = 'https://github.com/imahdimir/test-private'
-rp = GithubDataRepo(ur)
+rp = GitHubDataRepo(ur)
 rp.clone_overwrite()
 
 ##
